@@ -46,10 +46,8 @@ impl From<LitStr> for RegexCode {
         let regex = regex::Regex::new(&regex_string).unwrap();
 
         let build = quote! {{
-            use lazy_regex::once_cell::sync::OnceCell;
-            static RE: OnceCell::<regex::Regex> = OnceCell::new();
-            RE.get_or_init(|| {
-                // println!("compiling regex {:?}", #regex_string);
+            Lazy::new(|| {
+                //println!("compiling regex {:?}", #regex_string);
                 let mut builder = regex::RegexBuilder::new(#regex_string);
                 builder.case_insensitive(#case_insensitive);
                 builder.multi_line(#multi_line);
@@ -73,7 +71,32 @@ impl From<LitStr> for RegexCode {
 #[proc_macro]
 pub fn regex(input: TokenStream) -> TokenStream {
     let lit_str = syn::parse::<syn::LitStr>(input).unwrap();
-    RegexCode::from(lit_str).build.into()
+    let regex_build = RegexCode::from(lit_str).build;
+    let q = quote! {{
+        use lazy_regex::Lazy;
+        static RE: Lazy<regex::Regex> = #regex_build;
+        &RE
+    }};
+    q.into()
+}
+
+/// return an instance of `once_cell::sync::Lazy<regex::Regex>` that
+/// you can use in a public static declaration.
+///
+/// Example:
+///
+/// ```
+/// use lazy_regex::*;
+///
+/// pub static GLOBAL_REX: Lazy<Regex> = lazy_regex!("^ab+$"i);
+/// ```
+///
+/// As for other macros, the regex is checked at compilation time.
+#[proc_macro]
+pub fn lazy_regex(input: TokenStream) -> TokenStream {
+    let lit_str = syn::parse::<syn::LitStr>(input).unwrap();
+    let regex_build = RegexCode::from(lit_str).build;
+    regex_build.into()
 }
 
 /// wrapping of the two arguments given to one of the
@@ -114,7 +137,9 @@ pub fn regex_is_match(input: TokenStream) -> TokenStream {
     let regex_build = RegexCode::from(regex_and_expr_args.regex_str).build;
     let value = regex_and_expr_args.value;
     let q = quote! {{
-        #regex_build.is_match(#value)
+        use lazy_regex::Lazy;
+        static RE: Lazy<regex::Regex> = #regex_build;
+        RE.is_match(#value)
     }};
     q.into()
 }
@@ -134,7 +159,9 @@ pub fn regex_find(input: TokenStream) -> TokenStream {
     let regex_build = regex_code.build;
     let value = regex_and_expr_args.value;
     let q = quote! {{
-        #regex_build.find(#value).map(|mat| mat.as_str())
+        use lazy_regex::Lazy;
+        static RE: Lazy<regex::Regex> = #regex_build;
+        RE.find(#value).map(|mat| mat.as_str())
     }};
     q.into()
 }
@@ -162,7 +189,9 @@ pub fn regex_captures(input: TokenStream) -> TokenStream {
             caps.get(#i).map_or("", |c| c.as_str())
         });
     let q = quote! {{
-        #regex_build.captures(#value)
+        use lazy_regex::Lazy;
+        static RE: Lazy<regex::Regex> = #regex_build;
+        RE.captures(#value)
             .map(|caps| (
                 #(#groups),*
             ))
